@@ -1,20 +1,8 @@
-/*************************************************************************************
- *  Copyright 2016 by Sebastian Kügler <sebas@kde.org>                               *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2016 Sebastian Kügler <sebas@kde.org>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #include <QCoreApplication>
 #include <QObject>
@@ -96,7 +84,7 @@ void TestDpmsClient::initTestCase()
         } else {
             qDebug() << QStringLiteral("Compositor does not provid a DpmsManager");
         }
-        emit this->dpmsAnnounced();
+        Q_EMIT  this->dpmsAnnounced();
     });
     m_registry->setup();
 
